pub struct ClientWrapper {
pub path_provider: PathProvider,
/* private fields */
}Expand description
Wrapper to run a Linera client command.
Fields
path_provider: PathProviderProvides the working directory for the client’s files.
Implementations
Sourceimpl ClientWrapper
impl ClientWrapper
Sourcepub fn new(
path_provider: PathProvider,
network: Network,
testing_prng_seed: Option<u64>,
id: usize,
on_drop: OnClientDrop,
) -> Self
pub fn new( path_provider: PathProvider, network: Network, testing_prng_seed: Option<u64>, id: usize, on_drop: OnClientDrop, ) -> Self
Creates a new client wrapper with the default extra arguments.
Sourcepub fn new_with_extra_args(
path_provider: PathProvider,
network: Network,
testing_prng_seed: Option<u64>,
id: usize,
on_drop: OnClientDrop,
extra_args: Vec<String>,
binary_dir: Option<PathBuf>,
) -> Self
pub fn new_with_extra_args( path_provider: PathProvider, network: Network, testing_prng_seed: Option<u64>, id: usize, on_drop: OnClientDrop, extra_args: Vec<String>, binary_dir: Option<PathBuf>, ) -> Self
Creates a new client wrapper with the given extra arguments and binary directory.
Sourcepub async fn project_new(
&self,
project_name: &str,
linera_root: &Path,
) -> Result<TempDir>
pub async fn project_new( &self, project_name: &str, linera_root: &Path, ) -> Result<TempDir>
Runs linera project new.
Sourcepub async fn project_publish<T: Serialize>(
&self,
path: PathBuf,
required_application_ids: Vec<String>,
publisher: impl Into<Option<ChainId>>,
argument: &T,
) -> Result<String>
pub async fn project_publish<T: Serialize>( &self, path: PathBuf, required_application_ids: Vec<String>, publisher: impl Into<Option<ChainId>>, argument: &T, ) -> Result<String>
Runs linera project publish.
Sourcepub async fn project_test(&self, path: &Path) -> Result<()>
pub async fn project_test(&self, path: &Path) -> Result<()>
Runs linera project test.
Sourcepub async fn create_genesis_config(
&self,
num_other_initial_chains: u32,
initial_funding: Amount,
policy_config: ResourceControlPolicyConfig,
http_allow_list: Option<Vec<String>>,
) -> Result<()>
pub async fn create_genesis_config( &self, num_other_initial_chains: u32, initial_funding: Amount, policy_config: ResourceControlPolicyConfig, http_allow_list: Option<Vec<String>>, ) -> Result<()>
Runs linera create-genesis-config.
Sourcepub async fn wallet_init(&self, faucet: Option<&Faucet>) -> Result<()>
pub async fn wallet_init(&self, faucet: Option<&Faucet>) -> Result<()>
Runs linera wallet init. The genesis config is read from genesis.json, or from the
faucet if provided.
Sourcepub async fn request_chain(
&self,
faucet: &Faucet,
set_default: bool,
) -> Result<(ChainId, AccountOwner)>
pub async fn request_chain( &self, faucet: &Faucet, set_default: bool, ) -> Result<(ChainId, AccountOwner)>
Runs linera wallet request-chain.
Sourcepub async fn publish_and_create<A: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>(
&self,
contract: PathBuf,
service: PathBuf,
vm_runtime: VmRuntime,
parameters: &Parameters,
argument: &InstantiationArgument,
required_application_ids: &[ApplicationId],
publisher: impl Into<Option<ChainId>>,
) -> Result<ApplicationId<A>>
pub async fn publish_and_create<A: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>( &self, contract: PathBuf, service: PathBuf, vm_runtime: VmRuntime, parameters: &Parameters, argument: &InstantiationArgument, required_application_ids: &[ApplicationId], publisher: impl Into<Option<ChainId>>, ) -> Result<ApplicationId<A>>
Runs linera wallet publish-and-create.
Sourcepub async fn publish_module<Abi, Parameters, InstantiationArgument>(
&self,
contract: PathBuf,
service: PathBuf,
vm_runtime: VmRuntime,
publisher: impl Into<Option<ChainId>>,
) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
pub async fn publish_module<Abi, Parameters, InstantiationArgument>( &self, contract: PathBuf, service: PathBuf, vm_runtime: VmRuntime, publisher: impl Into<Option<ChainId>>, ) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
Runs linera publish-module.
Sourcepub async fn publish_module_with_formats<Abi, Parameters, InstantiationArgument>(
&self,
contract: PathBuf,
service: PathBuf,
formats: Option<PathBuf>,
vm_runtime: VmRuntime,
publisher: impl Into<Option<ChainId>>,
) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
pub async fn publish_module_with_formats<Abi, Parameters, InstantiationArgument>( &self, contract: PathBuf, service: PathBuf, formats: Option<PathBuf>, vm_runtime: VmRuntime, publisher: impl Into<Option<ChainId>>, ) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
Runs linera publish-module with an optional --formats SNAP file path.
Sourcepub async fn create_application<Abi: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>(
&self,
module_id: &ModuleId<Abi, Parameters, InstantiationArgument>,
parameters: &Parameters,
argument: &InstantiationArgument,
required_application_ids: &[ApplicationId],
creator: impl Into<Option<ChainId>>,
) -> Result<ApplicationId<Abi>>
pub async fn create_application<Abi: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>( &self, module_id: &ModuleId<Abi, Parameters, InstantiationArgument>, parameters: &Parameters, argument: &InstantiationArgument, required_application_ids: &[ApplicationId], creator: impl Into<Option<ChainId>>, ) -> Result<ApplicationId<Abi>>
Runs linera create-application.
Sourcepub async fn run_node_service(
&self,
port: impl Into<Option<u16>>,
process_inbox: ProcessInbox,
) -> Result<NodeService>
pub async fn run_node_service( &self, port: impl Into<Option<u16>>, process_inbox: ProcessInbox, ) -> Result<NodeService>
Runs linera service.
Sourcepub async fn run_node_service_with_options(
&self,
port: impl Into<Option<u16>>,
process_inbox: ProcessInbox,
operator_application_ids: &[ApplicationId],
operators: &[(String, PathBuf)],
read_only: bool,
) -> Result<NodeService>
pub async fn run_node_service_with_options( &self, port: impl Into<Option<u16>>, process_inbox: ProcessInbox, operator_application_ids: &[ApplicationId], operators: &[(String, PathBuf)], read_only: bool, ) -> Result<NodeService>
Runs linera service with optional task processor configuration.
Sourcepub async fn run_node_service_with_all_options(
&self,
port: impl Into<Option<u16>>,
process_inbox: ProcessInbox,
operator_application_ids: &[ApplicationId],
operators: &[(String, PathBuf)],
read_only: bool,
allowed_subscriptions: &[String],
subscription_ttls: &[(String, u64)],
) -> Result<NodeService>
pub async fn run_node_service_with_all_options( &self, port: impl Into<Option<u16>>, process_inbox: ProcessInbox, operator_application_ids: &[ApplicationId], operators: &[(String, PathBuf)], read_only: bool, allowed_subscriptions: &[String], subscription_ttls: &[(String, u64)], ) -> Result<NodeService>
Runs linera service with all available options.
Sourcepub async fn run_node_service_with_controller(
&self,
port: impl Into<Option<u16>>,
process_inbox: ProcessInbox,
controller_id: &ApplicationId,
operators: &[(String, PathBuf)],
) -> Result<NodeService>
pub async fn run_node_service_with_controller( &self, port: impl Into<Option<u16>>, process_inbox: ProcessInbox, controller_id: &ApplicationId, operators: &[(String, PathBuf)], ) -> Result<NodeService>
Runs linera service with a controller application.
Sourcepub async fn query_validator(&self, address: &str) -> Result<CryptoHash>
pub async fn query_validator(&self, address: &str) -> Result<CryptoHash>
Runs linera validator query
Sourcepub async fn query_validators(&self, chain_id: Option<ChainId>) -> Result<()>
pub async fn query_validators(&self, chain_id: Option<ChainId>) -> Result<()>
Runs linera validator list.
Sourcepub async fn sync_validator(
&self,
chain_ids: impl IntoIterator<Item = &ChainId>,
validator_address: impl Into<String>,
) -> Result<()>
pub async fn sync_validator( &self, chain_ids: impl IntoIterator<Item = &ChainId>, validator_address: impl Into<String>, ) -> Result<()>
Runs linera sync-validator.
Sourcepub async fn validator_benchmark(
&self,
address: impl Into<String>,
chains: impl IntoIterator<Item = &ChainId>,
extra_args: &[&str],
) -> Result<String>
pub async fn validator_benchmark( &self, address: impl Into<String>, chains: impl IntoIterator<Item = &ChainId>, extra_args: &[&str], ) -> Result<String>
Runs linera validator benchmark and returns its stdout.
Sourcepub async fn run_faucet(
&self,
port: impl Into<Option<u16>>,
chain_id: Option<ChainId>,
amount: Amount,
) -> Result<FaucetService>
pub async fn run_faucet( &self, port: impl Into<Option<u16>>, chain_id: Option<ChainId>, amount: Amount, ) -> Result<FaucetService>
Runs linera faucet.
Sourcepub async fn local_balance(&self, account: Account) -> Result<Amount>
pub async fn local_balance(&self, account: Account) -> Result<Amount>
Runs linera local-balance.
Sourcepub async fn query_balance(&self, account: Account) -> Result<Amount>
pub async fn query_balance(&self, account: Account) -> Result<Amount>
Runs linera query-balance.
Sourcepub async fn query_application_json<T: DeserializeOwned>(
&self,
chain_id: ChainId,
application_id: ApplicationId,
query: impl AsRef<str>,
) -> Result<T>
pub async fn query_application_json<T: DeserializeOwned>( &self, chain_id: ChainId, application_id: ApplicationId, query: impl AsRef<str>, ) -> Result<T>
Runs linera query-application and parses the JSON result.
Sourcepub async fn process_inbox(&self, chain_id: ChainId) -> Result<()>
pub async fn process_inbox(&self, chain_id: ChainId) -> Result<()>
Runs linera process-inbox.
Sourcepub async fn transfer(
&self,
amount: Amount,
from: ChainId,
to: ChainId,
) -> Result<()>
pub async fn transfer( &self, amount: Amount, from: ChainId, to: ChainId, ) -> Result<()>
Runs linera transfer.
Sourcepub async fn transfer_with_silent_logs(
&self,
amount: Amount,
from: ChainId,
to: ChainId,
) -> Result<()>
pub async fn transfer_with_silent_logs( &self, amount: Amount, from: ChainId, to: ChainId, ) -> Result<()>
Runs linera transfer with no logging.
Sourcepub async fn transfer_with_accounts(
&self,
amount: Amount,
from: Account,
to: Account,
) -> Result<()>
pub async fn transfer_with_accounts( &self, amount: Amount, from: Account, to: Account, ) -> Result<()>
Runs linera transfer with owner accounts.
Sourcepub async fn benchmark(&self, args: BenchmarkCommand) -> Result<()>
pub async fn benchmark(&self, args: BenchmarkCommand) -> Result<()>
Runs linera benchmark.
Sourcepub async fn benchmark_detached(
&self,
args: BenchmarkCommand,
tx: Sender<()>,
) -> Result<(Child, JoinHandle<()>, JoinHandle<()>)>
pub async fn benchmark_detached( &self, args: BenchmarkCommand, tx: Sender<()>, ) -> Result<(Child, JoinHandle<()>, JoinHandle<()>)>
Runs linera benchmark, but detached: don’t wait for the command to finish, just spawn it
and return the child process, and the handles to the stdout and stderr.
Sourcepub async fn open_chain_super_owner(
&self,
from: ChainId,
owner: Option<AccountOwner>,
initial_balance: Amount,
) -> Result<(ChainId, AccountOwner)>
pub async fn open_chain_super_owner( &self, from: ChainId, owner: Option<AccountOwner>, initial_balance: Amount, ) -> Result<(ChainId, AccountOwner)>
Runs linera open-chain --super-owner.
Sourcepub async fn open_chain(
&self,
from: ChainId,
owner: Option<AccountOwner>,
initial_balance: Amount,
) -> Result<(ChainId, AccountOwner)>
pub async fn open_chain( &self, from: ChainId, owner: Option<AccountOwner>, initial_balance: Amount, ) -> Result<(ChainId, AccountOwner)>
Runs linera open-chain.
Sourcepub async fn open_and_assign(
&self,
client: &ClientWrapper,
initial_balance: Amount,
) -> Result<ChainId>
pub async fn open_and_assign( &self, client: &ClientWrapper, initial_balance: Amount, ) -> Result<ChainId>
Runs linera open-chain then linera assign.
Sourcepub async fn open_multi_owner_chain(
&self,
from: ChainId,
owners: BTreeMap<AccountOwner, u64>,
multi_leader_rounds: u32,
balance: Amount,
base_timeout_ms: u64,
) -> Result<ChainId>
pub async fn open_multi_owner_chain( &self, from: ChainId, owners: BTreeMap<AccountOwner, u64>, multi_leader_rounds: u32, balance: Amount, base_timeout_ms: u64, ) -> Result<ChainId>
Runs linera open-multi-owner-chain and returns the new chain’s ID.
Sourcepub async fn change_ownership(
&self,
chain_id: ChainId,
super_owners: Vec<AccountOwner>,
owners: Vec<AccountOwner>,
) -> Result<()>
pub async fn change_ownership( &self, chain_id: ChainId, super_owners: Vec<AccountOwner>, owners: Vec<AccountOwner>, ) -> Result<()>
Runs linera change-ownership to set the super owners and owners of a chain.
Sourcepub async fn change_application_permissions(
&self,
chain_id: ChainId,
application_permissions: ApplicationPermissions,
) -> Result<()>
pub async fn change_application_permissions( &self, chain_id: ChainId, application_permissions: ApplicationPermissions, ) -> Result<()>
Runs linera change-application-permissions for the given chain.
Sourcepub async fn follow_chain(&self, chain_id: ChainId, sync: bool) -> Result<()>
pub async fn follow_chain(&self, chain_id: ChainId, sync: bool) -> Result<()>
Runs linera wallet follow-chain CHAIN_ID.
Sourcepub async fn forget_chain(&self, chain_id: ChainId) -> Result<()>
pub async fn forget_chain(&self, chain_id: ChainId) -> Result<()>
Runs linera wallet forget-chain CHAIN_ID.
Sourcepub async fn set_default_chain(&self, chain_id: ChainId) -> Result<()>
pub async fn set_default_chain(&self, chain_id: ChainId) -> Result<()>
Runs linera wallet set-default CHAIN_ID.
Sourcepub async fn retry_pending_block(
&self,
chain_id: Option<ChainId>,
) -> Result<Option<CryptoHash>>
pub async fn retry_pending_block( &self, chain_id: Option<ChainId>, ) -> Result<Option<CryptoHash>>
Runs linera retry-pending-block for the given chain.
Sourcepub async fn publish_data_blob(
&self,
path: &Path,
chain_id: Option<ChainId>,
) -> Result<CryptoHash>
pub async fn publish_data_blob( &self, path: &Path, chain_id: Option<ChainId>, ) -> Result<CryptoHash>
Runs linera publish-data-blob.
Sourcepub async fn read_data_blob(
&self,
hash: CryptoHash,
chain_id: Option<ChainId>,
) -> Result<()>
pub async fn read_data_blob( &self, hash: CryptoHash, chain_id: Option<ChainId>, ) -> Result<()>
Runs linera read-data-blob.
Sourcepub fn load_wallet(&self) -> Result<Wallet>
pub fn load_wallet(&self) -> Result<Wallet>
Reads the wallet from disk.
Sourcepub fn load_keystore(&self) -> Result<InMemorySigner>
pub fn load_keystore(&self) -> Result<InMemorySigner>
Reads the keystore from disk.
Sourcepub fn wallet_path(&self) -> PathBuf
pub fn wallet_path(&self) -> PathBuf
Returns the path to the wallet file.
Sourcepub fn keystore_path(&self) -> PathBuf
pub fn keystore_path(&self) -> PathBuf
Returns the path to the keystore file.
Sourcepub fn storage_path(&self) -> &str
pub fn storage_path(&self) -> &str
Returns the storage configuration string.
Sourcepub fn get_owner(&self) -> Option<AccountOwner>
pub fn get_owner(&self) -> Option<AccountOwner>
Returns the owner of the wallet’s default chain, if any.
Sourcepub fn is_chain_present_in_wallet(&self, chain: ChainId) -> bool
pub fn is_chain_present_in_wallet(&self, chain: ChainId) -> bool
Returns whether the given chain is present in the wallet.
Sourcepub async fn set_validator(
&self,
validator_key: &(String, String),
port: usize,
votes: usize,
) -> Result<()>
pub async fn set_validator( &self, validator_key: &(String, String), port: usize, votes: usize, ) -> Result<()>
Runs linera validator add for the given validator key, port, and number of votes.
Sourcepub async fn remove_validator(&self, validator_key: &str) -> Result<()>
pub async fn remove_validator(&self, validator_key: &str) -> Result<()>
Runs linera validator remove for the given validator public key.
Sourcepub async fn change_validators(
&self,
add_validators: &[(String, String, usize, usize)],
modify_validators: &[(String, String, usize, usize)],
remove_validators: &[String],
) -> Result<()>
pub async fn change_validators( &self, add_validators: &[(String, String, usize, usize)], modify_validators: &[(String, String, usize, usize)], remove_validators: &[String], ) -> Result<()>
Runs linera validator update to add, modify, and remove validators in one batch.
Sourcepub async fn revoke_epochs(&self, epoch: Epoch) -> Result<()>
pub async fn revoke_epochs(&self, epoch: Epoch) -> Result<()>
Runs linera revoke-epochs up to the given epoch.
Sourcepub async fn set_resource_control_policy(
&self,
overrides: ResourceControlPolicyOverrides,
) -> Result<()>
pub async fn set_resource_control_policy( &self, overrides: ResourceControlPolicyOverrides, ) -> Result<()>
Runs linera resource-control-policy with the given overrides.
Sourcepub async fn keygen(&self) -> Result<AccountOwner>
pub async fn keygen(&self) -> Result<AccountOwner>
Runs linera keygen.
Sourcepub fn default_chain(&self) -> Option<ChainId>
pub fn default_chain(&self) -> Option<ChainId>
Returns the default chain.
Sourcepub async fn assign(&self, owner: AccountOwner, chain_id: ChainId) -> Result<()>
pub async fn assign(&self, owner: AccountOwner, chain_id: ChainId) -> Result<()>
Runs linera assign.
Sourcepub async fn set_preferred_owner(
&self,
chain_id: ChainId,
owner: Option<AccountOwner>,
) -> Result<()>
pub async fn set_preferred_owner( &self, chain_id: ChainId, owner: Option<AccountOwner>, ) -> Result<()>
Runs linera set-preferred-owner for chain_id.
Sourceimpl ClientWrapper
impl ClientWrapper
Sourcepub async fn build_example(&self, name: &str) -> Result<(PathBuf, PathBuf)>
pub async fn build_example(&self, name: &str) -> Result<(PathBuf, PathBuf)>
Builds the example application with the given name from the examples directory.
Sourcepub async fn build_test_example(&self, name: &str) -> Result<(PathBuf, PathBuf)>
pub async fn build_test_example(&self, name: &str) -> Result<(PathBuf, PathBuf)>
Builds the test example application with the given name from the test fixtures.
Sourcepub fn example_path(name: &str) -> Result<PathBuf>
pub fn example_path(name: &str) -> Result<PathBuf>
Returns the path to the example application with the given name.
Sourcepub fn test_example_path(name: &str) -> Result<PathBuf>
pub fn test_example_path(name: &str) -> Result<PathBuf>
Returns the path to the test example application with the given name.