pub struct Faucet { /* private fields */ }Expand description
A faucet instance that can be queried.
Implementations
Sourceimpl Faucet
impl Faucet
Sourcepub fn new(url: String) -> Faucet
pub fn new(url: String) -> Faucet
Creates a faucet client querying the faucet service at the given URL.
Sourcepub async fn genesis_config(&self) -> Result<GenesisConfig, Error>
pub async fn genesis_config(&self) -> Result<GenesisConfig, Error>
Fetches the network’s genesis configuration from the faucet.
Sourcepub async fn version_info(&self) -> Result<VersionInfo, Error>
pub async fn version_info(&self) -> Result<VersionInfo, Error>
Fetches the faucet’s version information.
Sourcepub async fn claim(
&self,
owner: &AccountOwner,
) -> Result<ChainDescription, Error>
pub async fn claim( &self, owner: &AccountOwner, ) -> Result<ChainDescription, Error>
Claims a new chain for the given owner, returning its chain description.
Sourcepub async fn daily_claim(
&self,
owner: &AccountOwner,
) -> Result<ClaimOutcome, Error>
pub async fn daily_claim( &self, owner: &AccountOwner, ) -> Result<ClaimOutcome, Error>
Claims daily tokens for the given owner. The user must have already claimed a chain. Each user can claim once per 24-hour period.
Sourcepub async fn initial_claim(
&self,
owner: &AccountOwner,
) -> Result<Option<InitialClaim>, Error>
pub async fn initial_claim( &self, owner: &AccountOwner, ) -> Result<Option<InitialClaim>, Error>
Returns the initial claim for the given owner, if any.
Sourcepub async fn next_daily_claim(
&self,
owner: &AccountOwner,
) -> Result<Option<Timestamp>, Error>
pub async fn next_daily_claim( &self, owner: &AccountOwner, ) -> Result<Option<Timestamp>, Error>
Returns the earliest time at which the owner can make a daily claim.
If the returned timestamp is in the past (or now), the user can claim immediately.
Returns None if the user has not yet completed the initial claim.
Sourcepub async fn current_validators(
&self,
) -> Result<Vec<(Secp256k1PublicKey, String)>, Error>
pub async fn current_validators( &self, ) -> Result<Vec<(Secp256k1PublicKey, String)>, Error>
Returns the current validators’ public keys and network addresses.
Sourcepub async fn current_committee(&self) -> Result<Committee, Error>
pub async fn current_committee(&self) -> Result<Committee, Error>
Returns the current committee: its validators and resource-control policy.