pub struct NodeService { /* private fields */ }Expand description
A running node service that can be queried over GraphQL.
Implementations
Sourceimpl NodeService
impl NodeService
Sourcepub fn ensure_is_running(&mut self) -> Result<()>
pub fn ensure_is_running(&mut self) -> Result<()>
Checks that the node service process is still running.
Sourcepub async fn process_inbox(&self, chain_id: &ChainId) -> Result<Vec<CryptoHash>>
pub async fn process_inbox(&self, chain_id: &ChainId) -> Result<Vec<CryptoHash>>
Runs the processInbox GraphQL mutation for the given chain.
Sourcepub async fn sync(&self, chain_id: &ChainId) -> Result<u64>
pub async fn sync(&self, chain_id: &ChainId) -> Result<u64>
Runs the sync GraphQL mutation for the given chain.
Sourcepub async fn transfer(
&self,
chain_id: ChainId,
owner: AccountOwner,
recipient: Account,
amount: Amount,
) -> Result<CryptoHash>
pub async fn transfer( &self, chain_id: ChainId, owner: AccountOwner, recipient: Account, amount: Amount, ) -> Result<CryptoHash>
Transfers the given amount from an owner to a recipient via the transfer mutation.
Sourcepub async fn balance(&self, account: &Account) -> Result<Amount>
pub async fn balance(&self, account: &Account) -> Result<Amount>
Queries the balance of the given account.
Sourcepub fn make_application<A: ContractAbi>(
&self,
chain_id: &ChainId,
application_id: &ApplicationId<A>,
) -> Result<ApplicationWrapper<A>>
pub fn make_application<A: ContractAbi>( &self, chain_id: &ChainId, application_id: &ApplicationId<A>, ) -> Result<ApplicationWrapper<A>>
Returns an ApplicationWrapper for querying the given application over GraphQL.
Sourcepub async fn publish_data_blob(
&self,
chain_id: &ChainId,
bytes: Vec<u8>,
) -> Result<CryptoHash>
pub async fn publish_data_blob( &self, chain_id: &ChainId, bytes: Vec<u8>, ) -> Result<CryptoHash>
Publishes a data blob to the given chain via the publishDataBlob mutation.
Sourcepub async fn publish_module<Abi, Parameters, InstantiationArgument>(
&self,
chain_id: &ChainId,
contract: PathBuf,
service: PathBuf,
vm_runtime: VmRuntime,
) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
pub async fn publish_module<Abi, Parameters, InstantiationArgument>( &self, chain_id: &ChainId, contract: PathBuf, service: PathBuf, vm_runtime: VmRuntime, ) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
Publishes a module to the given chain via the publishModule mutation.
Sourcepub async fn query_committee_hash(
&self,
chain_id: &ChainId,
) -> Result<Option<CryptoHash>>
pub async fn query_committee_hash( &self, chain_id: &ChainId, ) -> Result<Option<CryptoHash>>
Queries the committee hash of the given chain.
Sourcepub async fn query_chain_epoch(&self, chain_id: &ChainId) -> Result<Epoch>
pub async fn query_chain_epoch(&self, chain_id: &ChainId) -> Result<Epoch>
Queries the current epoch of the given chain.
Sourcepub async fn events_from_index(
&self,
chain_id: &ChainId,
stream_id: &StreamId,
start_index: u32,
) -> Result<Vec<IndexAndEvent>>
pub async fn events_from_index( &self, chain_id: &ChainId, stream_id: &StreamId, start_index: u32, ) -> Result<Vec<IndexAndEvent>>
Queries the events of the given stream starting from the given index.
Sourcepub async fn query_node(&self, query: impl AsRef<str>) -> Result<Value>
pub async fn query_node(&self, query: impl AsRef<str>) -> Result<Value>
Posts the given GraphQL query to the node service, retrying on transient errors.
Sourcepub async fn create_application<Abi: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>(
&self,
chain_id: &ChainId,
module_id: &ModuleId<Abi, Parameters, InstantiationArgument>,
parameters: &Parameters,
argument: &InstantiationArgument,
required_application_ids: &[ApplicationId],
) -> Result<ApplicationId<Abi>>
pub async fn create_application<Abi: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>( &self, chain_id: &ChainId, module_id: &ModuleId<Abi, Parameters, InstantiationArgument>, parameters: &Parameters, argument: &InstantiationArgument, required_application_ids: &[ApplicationId], ) -> Result<ApplicationId<Abi>>
Creates an application from a published module via the createApplication mutation.
Sourcepub async fn chain_tip(
&self,
chain: ChainId,
) -> Result<Option<(CryptoHash, BlockHeight)>>
pub async fn chain_tip( &self, chain: ChainId, ) -> Result<Option<(CryptoHash, BlockHeight)>>
Obtains the hash and height of the chain’s tip block, as known by this node service.
Sourcepub async fn notifications(
&self,
chain_id: ChainId,
) -> Result<Pin<Box<impl Stream<Item = Result<Notification>>>>>
pub async fn notifications( &self, chain_id: ChainId, ) -> Result<Pin<Box<impl Stream<Item = Result<Notification>>>>>
Subscribes to the node service and returns a stream of notifications about a chain.