pub trait LineraNet {
// Required methods
fn ensure_is_running<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn make_client<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = ClientWrapper> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn terminate<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
A running Linera net.
Required Methods
Sourcefn ensure_is_running<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn ensure_is_running<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Checks that the net is still running and returns an error otherwise.
Sourcefn make_client<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = ClientWrapper> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn make_client<'life0, 'async_trait>(
&'life0 mut self,
) -> Pin<Box<dyn Future<Output = ClientWrapper> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Creates a new client to interact with the net.