pub trait LineraNetConfig {
type Net: LineraNet + Sized + Send + Sync + 'static;
// Required method
fn instantiate<'async_trait>(
self,
) -> Pin<Box<dyn Future<Output = Result<(Self::Net, ClientWrapper)>> + Send + 'async_trait>>
where Self: 'async_trait;
}Expand description
The information needed to start a Linera net of a particular kind.
Required Associated Types
Required Methods
Sourcefn instantiate<'async_trait>(
self,
) -> Pin<Box<dyn Future<Output = Result<(Self::Net, ClientWrapper)>> + Send + 'async_trait>>where
Self: 'async_trait,
fn instantiate<'async_trait>(
self,
) -> Pin<Box<dyn Future<Output = Result<(Self::Net, ClientWrapper)>> + Send + 'async_trait>>where
Self: 'async_trait,
Starts the Linera net and returns it together with a client to interact with it.