pub struct NodeService { /* private fields */ }Implementations
Sourceimpl NodeService
impl NodeService
pub async fn terminate(self) -> Result<()>
pub fn port(&self) -> u16
pub fn ensure_is_running(&mut self) -> Result<()>
pub async fn process_inbox(&self, chain_id: &ChainId) -> Result<Vec<CryptoHash>>
pub async fn sync(&self, chain_id: &ChainId) -> Result<u64>
pub async fn transfer( &self, chain_id: ChainId, owner: AccountOwner, recipient: Account, amount: Amount, ) -> Result<CryptoHash>
pub async fn balance(&self, account: &Account) -> Result<Amount>
pub fn make_application<A: ContractAbi>( &self, chain_id: &ChainId, application_id: &ApplicationId<A>, ) -> Result<ApplicationWrapper<A>>
pub async fn publish_data_blob( &self, chain_id: &ChainId, bytes: Vec<u8>, ) -> Result<CryptoHash>
pub async fn publish_module<Abi, Parameters, InstantiationArgument>( &self, chain_id: &ChainId, contract: PathBuf, service: PathBuf, vm_runtime: VmRuntime, ) -> Result<ModuleId<Abi, Parameters, InstantiationArgument>>
pub async fn query_committees( &self, chain_id: &ChainId, ) -> Result<BTreeMap<Epoch, Committee>>
pub async fn events_from_index( &self, chain_id: &ChainId, stream_id: &StreamId, start_index: u32, ) -> Result<Vec<IndexAndEvent>>
pub async fn query_node(&self, query: impl AsRef<str>) -> Result<Value>
pub async fn create_application<Abi: ContractAbi, Parameters: Serialize, InstantiationArgument: Serialize>( &self, chain_id: &ChainId, module_id: &ModuleId<Abi, Parameters, InstantiationArgument>, parameters: &Parameters, argument: &InstantiationArgument, required_application_ids: &[ApplicationId], ) -> Result<ApplicationId<Abi>>
Sourcepub async fn chain_tip(
&self,
chain: ChainId,
) -> Result<Option<(CryptoHash, BlockHeight)>>
pub async fn chain_tip( &self, chain: ChainId, ) -> Result<Option<(CryptoHash, BlockHeight)>>
Obtains the hash and height of the chain’s tip block, as known by this node service.
Sourcepub async fn notifications(
&self,
chain_id: ChainId,
) -> Result<Pin<Box<impl Stream<Item = Result<Notification>>>>>
pub async fn notifications( &self, chain_id: ChainId, ) -> Result<Pin<Box<impl Stream<Item = Result<Notification>>>>>
Subscribes to the node service and returns a stream of notifications about a chain.